@@ -1,6 +1,6 @@
 /***************************************************************************
  *   Copyright (C) 2015 The Qt Company Ltd.                                *
- *   Copyright (C) 2016-2025 Ilya Kotov, forkotov02@ya.ru                  *
+ *   Copyright (C) 2016-2026 Ilya Kotov, forkotov02@ya.ru                  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -55,8 +55,18 @@ QPixmap QGtk2Painter::renderTheme(uchar *bdata, uchar *wdata, const QRect &rect)
                      QImage::Format_ARGB32_Premultiplied : QImage::Format_RGB32);
 
     if (m_hflipped || m_vflipped) {
+#if QT_VERSION >= QT_VERSION_CHECK(6, 9, 0)
+        Qt::Orientations orient;
+        if (m_hflipped)
+            orient |= Qt::Horizontal;
+        if (m_vflipped)
+            orient |= Qt::Vertical;
+        return QPixmap::fromImage(converted.flipped(orient));
+#else
         return QPixmap::fromImage(converted.mirrored(m_hflipped, m_vflipped));
+#endif
     }
+
     // on raster graphicssystem we need to do a copy here, because
     // we intend to deallocate the qimage bits shortly after...
     return QPixmap::fromImage(converted.copy());
