@@ -1,6 +1,6 @@
 /***************************************************************************
  *   Copyright (C) 2015 The Qt Company Ltd.                                *
- *   Copyright (C) 2016-2025 Ilya Kotov, forkotov02@ya.ru                  *
+ *   Copyright (C) 2016-2026 Ilya Kotov, forkotov02@ya.ru                  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -222,69 +222,71 @@ void drawDial(const QStyleOptionSlider *option, QPainter *painter)
 
 #if (QT_VERSION >= QT_VERSION_CHECK(6, 9, 0))
     QCachedPainter p(painter, QLatin1StringView("qdial"), option);
+    if (p.needsPainting()) {
 #else
     BEGIN_STYLE_PIXMAPCACHE(QString::fromLatin1("qdial"));
 #endif
-    p->setRenderHint(QPainter::Antialiasing);
+        p->setRenderHint(QPainter::Antialiasing);
 
-    const qreal d_ = r / 6;
-    const qreal dx = option->rect.x() + d_ + (width - 2 * r) / 2 + 1;
-    const qreal dy = option->rect.y() + d_ + (height - 2 * r) / 2 + 1;
+        const qreal d_ = r / 6;
+        const qreal dx = option->rect.x() + d_ + (width - 2 * r) / 2 + 1;
+        const qreal dy = option->rect.y() + d_ + (height - 2 * r) / 2 + 1;
 
-    QRectF br = QRectF(dx + 0.5, dy + 0.5,
-                       int(r * 2 - 2 * d_ - 2),
-                       int(r * 2 - 2 * d_ - 2));
-    buttonColor.setHsv(buttonColor .hue(),
-                       qMin(140, buttonColor .saturation()),
-                       qMax(180, buttonColor.value()));
+        QRectF br = QRectF(dx + 0.5, dy + 0.5,
+                           int(r * 2 - 2 * d_ - 2),
+                           int(r * 2 - 2 * d_ - 2));
+        buttonColor.setHsv(buttonColor .hue(),
+                           qMin(140, buttonColor .saturation()),
+                           qMax(180, buttonColor.value()));
 
-    if (enabled) {
-        // Drop shadow
-        qreal shadowSize = qMax(1.0, penSize/2.0);
-        QRectF shadowRect= br.adjusted(-2*shadowSize, -2*shadowSize,
-                                       2*shadowSize, 2*shadowSize);
-        QRadialGradient shadowGradient(shadowRect.center().x(),
-                                       shadowRect.center().y(), shadowRect.width()/2.0,
-                                       shadowRect.center().x(), shadowRect.center().y());
-        shadowGradient.setColorAt(qreal(0.91), QColor(0, 0, 0, 40));
-        shadowGradient.setColorAt(qreal(1.0), Qt::transparent);
-        p->setBrush(shadowGradient);
-        p->setPen(Qt::NoPen);
-        p->translate(shadowSize, shadowSize);
-        p->drawEllipse(shadowRect);
-        p->translate(-shadowSize, -shadowSize);
+        if (enabled) {
+            // Drop shadow
+            qreal shadowSize = qMax(1.0, penSize/2.0);
+            QRectF shadowRect= br.adjusted(-2*shadowSize, -2*shadowSize,
+                                            2*shadowSize, 2*shadowSize);
+            QRadialGradient shadowGradient(shadowRect.center().x(),
+                                           shadowRect.center().y(), shadowRect.width()/2.0,
+                                           shadowRect.center().x(), shadowRect.center().y());
+            shadowGradient.setColorAt(qreal(0.91), QColor(0, 0, 0, 40));
+            shadowGradient.setColorAt(qreal(1.0), Qt::transparent);
+            p->setBrush(shadowGradient);
+            p->setPen(Qt::NoPen);
+            p->translate(shadowSize, shadowSize);
+            p->drawEllipse(shadowRect);
+            p->translate(-shadowSize, -shadowSize);
 
-        // Main gradient
-        QRadialGradient gradient(br.center().x() - br.width()/3, dy,
-                                 br.width()*1.3, br.center().x(),
-                                 br.center().y() - br.height()/2);
-        gradient.setColorAt(0, buttonColor.lighter(110));
-        gradient.setColorAt(qreal(0.5), buttonColor);
-        gradient.setColorAt(qreal(0.501), buttonColor.darker(102));
-        gradient.setColorAt(1, buttonColor.darker(115));
-        p->setBrush(gradient);
-    } else {
+            // Main gradient
+            QRadialGradient gradient(br.center().x() - br.width()/3, dy,
+                                     br.width()*1.3, br.center().x(),
+                                     br.center().y() - br.height()/2);
+            gradient.setColorAt(0, buttonColor.lighter(110));
+            gradient.setColorAt(qreal(0.5), buttonColor);
+            gradient.setColorAt(qreal(0.501), buttonColor.darker(102));
+            gradient.setColorAt(1, buttonColor.darker(115));
+            p->setBrush(gradient);
+        } else {
+            p->setBrush(Qt::NoBrush);
+        }
+
+        p->setPen(QPen(buttonColor.darker(280)));
+        p->drawEllipse(br);
         p->setBrush(Qt::NoBrush);
-    }
+        p->setPen(buttonColor.lighter(110));
+        p->drawEllipse(br.adjusted(1, 1, -1, -1));
 
-    p->setPen(QPen(buttonColor.darker(280)));
-    p->drawEllipse(br);
-    p->setBrush(Qt::NoBrush);
-    p->setPen(buttonColor.lighter(110));
-    p->drawEllipse(br.adjusted(1, 1, -1, -1));
-
-    if (option->state & QStyle::State_HasFocus) {
-        QColor highlight = pal.highlight().color();
-        highlight.setHsv(highlight.hue(),
-                         qMin(160, highlight.saturation()),
-                         qMax(230, highlight.value()));
-        highlight.setAlpha(127);
-        p->setPen(QPen(highlight, 2.0));
-        p->setBrush(Qt::NoBrush);
-        p->drawEllipse(br.adjusted(-1, -1, 1, 1));
-    }
+        if (option->state & QStyle::State_HasFocus) {
+            QColor highlight = pal.highlight().color();
+            highlight.setHsv(highlight.hue(),
+                             qMin(160, highlight.saturation()),
+                             qMax(230, highlight.value()));
+            highlight.setAlpha(127);
+            p->setPen(QPen(highlight, 2.0));
+            p->setBrush(Qt::NoBrush);
+            p->drawEllipse(br.adjusted(-1, -1, 1, 1));
+        }
 
 #if (QT_VERSION >= QT_VERSION_CHECK(6, 9, 0))
+    }
     p.finish();
 #else
     END_STYLE_PIXMAPCACHE
